'use client'
import React from 'react'
import { Button } from "@heroui/react";
import { Image } from "@heroui/image";
import { FaRegCheckCircle } from "react-icons/fa";
import { CgMoreO } from "react-icons/cg";
import { IoMailOutline } from "react-icons/io5";
import Footer from '@/components/Footer';
import Link from 'next/link';

const page = () => {
    return (
        <>
            <main className='mx-3 xl:mx-20 mt-3 xl:mt-10 mb-10 lg:mb-28'>
                {/* HERO SECTION */}
                <div
                    className="flex flex-col justify-center items-start h-[12rem] p-5 md:p-10 rounded-3xl bg-cover bg-center bg-fixed"
                    style={{
                        backgroundImage: "url('/old-hero.jpg')",
                    }}
                >
                    <p className='text-white text-sm md:text-medium font-medium'><Link className='hover:underline' href={'/'}>HOME</Link> / <Link href={'/service'} className="hover:underline">SERVICE</Link> / <Link href={'/service/painting'} className="hover:underline text-yellow-500">PAINTING</Link></p>
                    <p className="text-white font-semibold text-4xl lg:text-5xl mt-3">Painting</p>
                </div>
                {/* HERO SECTION */}

                {/* SECTION 1 */}
                <div className='mt-10'>
                    <p className='text-2xl md:text-4xl font-semibold mt-3 text-slate-800'>Interior / Exterior Paint & Repair</p>
                    <p className='text-lg md:text-xl mt-5 md:mt-8 text-gray-600 leading-8'>The interior can include one wall to the entire house. On the exterior, we can do anything from siding repair all the way up to painting the entire house.</p>
                    <p className='text-lg md:text-xl mt-2 font-light text-gray-600 leading-8'>We can also inspect your fence to see if we could restore to make it like new... saving you thousands from replacing it. <Link href={'/service/fencing'} className='text-yellow-500 hover:underline'>Learn More</Link></p>
                </div>
                {/* SECTION 1 */}
                <hr className='my-16' />

                {/* SECTION 2 */}
                <div className='lg:mt-28 flex flex-col md:flex-row gap-3 md:gap-0'>
                    <div className='w-full md:w-1/2'>
                        <Image
                            isBlurred
                            src='/service/painting.jpg'
                            alt='img'
                            className='w-3/4 mx-auto'
                        />
                    </div>

                    <div className='w-full md:w-1/2'>
                        <p className='text-2xl md:text-4xl font-semibold mt-3 text-slate-800'>
                            The best product & services for your money</p>
                        <div className="lists mt-8 flex ml-5 flex-col gap-3">
                            <div className='flex items-start gap-4'>
                                <FaRegCheckCircle className='text-yellow-500 text-[1.8rem] hidden lg:block' />
                                <span className="text-yellow-500 lg:hidden">-</span>
                                <p className='text-lg md:text-xl'>Our estimating gets done with the mindset of <br /><i>"lowest cost, maximize efficiency, highest quality"</i></p>
                            </div>
                            <div className='flex items-start gap-4'>
                                <FaRegCheckCircle className='text-yellow-500 text-[1.8rem] hidden lg:block' />
                                <span className="text-yellow-500 lg:hidden">-</span>
                                <p className='text-lg md:text-xl'>We match color to avoid needing to paint additional walls/surfaces for <span className="text-red-500">"matching purpose"</span></p>
                            </div>
                            <div className='flex items-start gap-4'>
                                <FaRegCheckCircle className='text-yellow-500 text-[1.8rem] hidden lg:block' />
                                <span className="text-yellow-500 lg:hidden">-</span>
                                <p className='text-lg md:text-xl'>We protect your property by masking & covering to avoid damage</p>
                            </div>
                        </div>

                    </div>

                </div>


                {/* LETS START SECTION */}
                <div className="mt-6 lg:mt-28 flex flex-col md:flex-row rounded-3xl bg-green-100/30">

                    <div className='w-full md:w-1/2 p-3 md:p-10'>
                        <p className='text-4xl lg:text-5xl font-semibold mt-3 text-slate-800'>Let's build something great <span className="text-yellow-500">together</span></p>
                        <p className='text-lg lg:text-xl mt-8 text-gray-600 leading-8'>Don’t wait any longer to bring your construction dreams to life. Partner with C&CGC and experience unparalleled service and quality.</p>
                        <Button as={Link} href='/contact' className='mt-5 lg:mt-10' variant='shadow' size='md' color='warning'>Contact Us <IoMailOutline /></Button>
                    </div>
                    <div className='w-full md:w-1/2 flex items-end'>
                        <Image
                            isBlurred
                            src='/cta.png'
                            alt='cta'
                            className='w-3/4 mx-auto'
                        />
                    </div>
                </div>
                {/* LETS START SECTION */}
            </main>
            <Footer />
        </>
    )
}

export default page